@@ -27,7 +27,7 @@ from visvis.utils.pypoints import Pointset, Point
 #
 from visvis.core import base
 from visvis.core.misc import Range, getColor, basestring
-from visvis.core.misc import Property, PropWithDraw, DrawAfter 
+from visvis.core.misc import Property, PropWithDraw, DrawAfter
 #
 from visvis.text import Text
 from visvis.core.line import lineStyles, PolarLine
@@ -36,8 +36,8 @@ from visvis.core.cameras import depthToZ, TwoDCamera, FlyCamera
 
 # A note about tick labels. We format these such that the width of the ticks
 # never becomes larger than 10 characters (including sign bit).
-# With a fontsize of 9, this needs little less than 70 pixels. The 
-# correction applied when visualizing axis (and ticks) is 60, because 
+# With a fontsize of 9, this needs little less than 70 pixels. The
+# correction applied when visualizing axis (and ticks) is 60, because
 # the default offset is 10 pixels for the axes.
 # See the docstring of GetTickTexts() for more info.
 
@@ -154,7 +154,7 @@ class AxisLabel(AxisText):
 def GetTickTexts(ticks):
     """ GetTickTexts(ticks)
     
-    Get tick labels of maximally 9 characters (plus sign char). 
+    Get tick labels of maximally 9 characters (plus sign char).
     
     All ticks will be formatted in the same manner, and with the same number
     of decimals. In exponential notation, the exponent is written with as
@@ -163,7 +163,7 @@ def GetTickTexts(ticks):
     The algorithm is to first test for each tick the number of characters
     before the dot, the number of decimals, and the number of chars for
     the exponent. Then the ticks are formatted only without exponent if
-    the first two chars (plus one for the dot) are less than 9.    
+    the first two chars (plus one for the dot) are less than 9.
     
     Examples are:
     xx.yyyyyy
@@ -219,7 +219,7 @@ def GetTickTexts(ticks):
             if tick == -0: tick = 0
             ticks2.append( f % tick )
     
-    elif maxChars1 < 9:        
+    elif maxChars1 < 9:
         # Do the best we can
         
         chars2 = 9 - (maxChars1+1)
@@ -249,8 +249,8 @@ def GetTickTexts(ticks):
 def GetTickText_deprecated(tick):
     """ GetTickText(tick)
     
-    Obtain text from a tick. Convert to exponential notation 
-    if necessary. 
+    Obtain text from a tick. Convert to exponential notation
+    if necessary.
     
     """
     
@@ -331,7 +331,7 @@ def GetTicks(p0, p1, lim, minTickDist=40, givenTicks=None):
         for tickValue in givenTicks:
             if tickValue >= lim.min and tickValue <= lim.max:
                 tickText = givenTicks[tickValue]
-                tickValues.append(tickValue)                
+                tickValues.append(tickValue)
                 if isinstance(tickText, basestring):
                     tickTexts.append(tickText)
                 else:
@@ -345,8 +345,8 @@ def GetTicks(p0, p1, lim, minTickDist=40, givenTicks=None):
         
         for i in range(len(givenTicks)):
             
-            # Get tick 
-            t = givenTicks[i]            
+            # Get tick
+            t = givenTicks[i]
             if isinstance(t, basestring):
                 tickValue = i
                 tickText = t
@@ -420,8 +420,8 @@ class BaseAxis(base.Wobject):
     #
     #  / \      _
     #   |       /|
-    #   | z    /        x   
-    #   |     /  y    -----> 
+    #   | z    /        x
+    #   |     /  y    ----->
     #
     
     
@@ -430,7 +430,7 @@ class BaseAxis(base.Wobject):
         
         # Make the axis the first wobject in the list. This somehow seems
         # right and makes the Axes.axis property faster.
-        if hasattr(parent, '_wobjects') and self in parent._wobjects:            
+        if hasattr(parent, '_wobjects') and self in parent._wobjects:
             parent._wobjects.remove(self)
             parent._wobjects.insert(0, self)
         
@@ -453,9 +453,9 @@ class BaseAxis(base.Wobject):
         
         # Corners of a cube in relative coordinates
         self._corners = tmp = Pointset(3)
-        tmp.append(0,0,0);  tmp.append(1,0,0);  tmp.append(0,1,0);
-        tmp.append(0,0,1);  tmp.append(1,1,0);  tmp.append(1,0,1);
-        tmp.append(0,1,1);  tmp.append(1,1,1);
+        tmp.append(0,0,0);  tmp.append(1,0,0);  tmp.append(0,1,0)
+        tmp.append(0,0,1);  tmp.append(1,1,0);  tmp.append(1,0,1)
+        tmp.append(0,1,1);  tmp.append(1,1,1)
         
         # Indices of the base corners for each dimension.
         # The order is very important, don't mess it up...
@@ -600,11 +600,11 @@ class BaseAxis(base.Wobject):
     
     @PropWithDraw
     def xTicks():
-        """ Get/Set the ticks for the x dimension. 
+        """ Get/Set the ticks for the x dimension.
         
         The value can be:
-          * None: the ticks are determined automatically. 
-          * A tuple/list/numpy_array with float or string values: Floats 
+          * None: the ticks are determined automatically.
+          * A tuple/list/numpy_array with float or string values: Floats
             specify at which location tickmarks should be drawn. Strings are
             drawn at integer positions corresponding to the index in the
             given list.
@@ -643,11 +643,11 @@ class BaseAxis(base.Wobject):
     
     @PropWithDraw
     def yTicks():
-        """ Get/Set the ticks for the y dimension. 
+        """ Get/Set the ticks for the y dimension.
         
         The value can be:
-          * None: the ticks are determined automatically. 
-          * A tuple/list/numpy_array with float or string values: Floats 
+          * None: the ticks are determined automatically.
+          * A tuple/list/numpy_array with float or string values: Floats
             specify at which location tickmarks should be drawn. Strings are
             drawn at integer positions corresponding to the index in the
             given list.
@@ -686,11 +686,11 @@ class BaseAxis(base.Wobject):
     
     @PropWithDraw
     def zTicks():
-        """ Get/Set the ticks for the z dimension. 
+        """ Get/Set the ticks for the z dimension.
         
         The value can be:
-          * None: the ticks are determined automatically. 
-          * A tuple/list/numpy_array with float or string values: Floats 
+          * None: the ticks are determined automatically.
+          * A tuple/list/numpy_array with float or string values: Floats
             specify at which location tickmarks should be drawn. Strings are
             drawn at integer positions corresponding to the index in the
             given list.
@@ -729,7 +729,7 @@ class BaseAxis(base.Wobject):
     
     @PropWithDraw
     def xLabel():
-        """ Get/Set the label for the x dimension. 
+        """ Get/Set the label for the x dimension.
         """
         def fget(self):
             return self._xlabel
@@ -739,7 +739,7 @@ class BaseAxis(base.Wobject):
     
     @PropWithDraw
     def yLabel():
-        """ Get/Set the label for the y dimension. 
+        """ Get/Set the label for the y dimension.
         """
         def fget(self):
             return self._ylabel
@@ -749,7 +749,7 @@ class BaseAxis(base.Wobject):
     
     @PropWithDraw
     def zLabel():
-        """ Get/Set the label for the z dimension. 
+        """ Get/Set the label for the z dimension.
         """
         def fget(self):
             return self._zlabel
@@ -845,7 +845,7 @@ class BaseAxis(base.Wobject):
     ## Help methods
     
     def _DestroyChildren(self):
-        """ Method to clean up the children (text objects). 
+        """ Method to clean up the children (text objects).
         """
         if self._children:
             for child in self.children:
@@ -906,7 +906,7 @@ class BaseAxis(base.Wobject):
 
 
     def _NextCornerIndex(self, i, d, vector_s):
-        """ Calculate the next corner index. 
+        """ Calculate the next corner index.
         """
         
         if d<2 and vector_s.x >= 0:
@@ -946,10 +946,10 @@ class CartesianAxis2D(BaseAxis):
     
     @PropWithDraw
     def xTicksAngle():
-        """ Get/Set the angle of the tick marks for te x-dimension. 
+        """ Get/Set the angle of the tick marks for te x-dimension.
         This can be used when the tick labels are long, to prevent
-        them from overlapping. Note that if this value is non-zero, 
-        the horizontal alignment is changed to left (instead of center). 
+        them from overlapping. Note that if this value is non-zero,
+        the horizontal alignment is changed to left (instead of center).
         """
         def fget(self):
             return self._xTicksAngle
@@ -1037,15 +1037,15 @@ class CartesianAxis2D(BaseAxis):
                     i0 = i
                     bestVal = val
 
-            # Get indices of the two next corners on which 
+            # Get indices of the two next corners on which
             # ridges we may draw grid lines
             i1 = self._NextCornerIndex(i0, d, vector_s)
-            i2 = self._NextCornerIndex(i1, d, vector_s)
+            # i2 = self._NextCornerIndex(i1, d, vector_s)
             
             # Get first corner and grid vectors
             firstCorner = corners4_c[i0]
             gv1 = corners4_c[i1] - corners4_c[i0]
-            gv2 = corners4_c[i2] - corners4_c[i1]
+            # gv2 = corners4_c[i2] - corners4_c[i1]
             
             # Get tick vector to indicate tick
             gv1s = corners4_s[i1] - corners4_s[i0]
@@ -1125,7 +1125,7 @@ class CartesianAxis2D(BaseAxis):
                 fig = axes.GetFigure()
                 if fig:
                     tmp1 = fig.position.width
-                    tmp2 = glu.gluProject(t.x, t.y, t.z)[0] 
+                    tmp2 = glu.gluProject(t.x, t.y, t.z)[0]
                     tmp2 += t.GetVertexLimits()[0][1] # Max of x
                     # Apply
                     if tmp1 < tmp2:
@@ -1211,7 +1211,7 @@ class CartesianAxis3D(BaseAxis):
         Also returns the lengths of the smallest vectors, for the
         calculation of the minimum tick distance.
         
-        """ 
+        """
         
         # Get the vectors
         vectors_c = []
@@ -1290,7 +1290,7 @@ class CartesianAxis3D(BaseAxis):
             corners4_c = [corners8_c[i] for i in tmp]
             corners4_s = [corners8_s[i] for i in tmp]
             
-            # Get directional vectors (i.e. ridges) corresponding to 
+            # Get directional vectors (i.e. ridges) corresponding to
             # (emanating from) the four corners. Also returns the length
             # of the shortest ridges (in screen coords)
             _vectors = self._GetRidgeVector(d, corners8_c, corners8_s)
@@ -1342,7 +1342,7 @@ class CartesianAxis3D(BaseAxis):
             # Draw edge lines (optionally to create a full box)
             for i in range(4):
                 if self._showBox or i in [i0, i1, i2]:
-                #if self._showBox or i ==i0: # for a real minimalistic axis
+                    #if self._showBox or i ==i0: # for a real minimalistic axis
                     # Note that we use world coordinates, rather than screen
                     # as the 2D axis does.
                     ppc.append(corners4_c[i])
@@ -1487,8 +1487,7 @@ class CartesianAxis(CartesianAxis2D, CartesianAxis3D):
 
 
 
-def GetPolarTicks(p0, radius, lim, angularRefPos, sense , minTickDist=100, \
-                  ticks=None):
+def GetPolarTicks(p0, radius, lim, angularRefPos, sense , minTickDist=100, ticks=None):
     """ GetPolarTicks(p0, radius, lim, angularRefPos, sense , minTickDist=100,
                        ticks=None)
                         
@@ -1634,8 +1633,7 @@ class PolarAxis2D(BaseAxis):
         drawObjs = axes.FindObjects(PolarLine)
         # Now set the transform for the PolarLine data
         for anObj in drawObjs:
-            anObj.TransformPolar(self._radialRange, \
-            self._angularRefPos, self._sense)
+            anObj.TransformPolar(self._radialRange, self._angularRefPos, self._sense)
     
     
     def _CreateLinesAndLabels(self, axes):
@@ -1803,10 +1801,10 @@ class PolarAxis2D(BaseAxis):
         yc = radiusMax_c * np.sin(theta)
         # ppb is the largest circle that will fit
         # and is used  to draw the  polar background poly
-        for x, y in  np.column_stack((xb, yb)):
+        for x, y in np.column_stack((xb, yb)):
             self.ppb.append(x, y, -10.0)
 
-        for x, y in  np.column_stack((xc, yc)):
+        for x, y in np.column_stack((xc, yc)):
             self.ppr.append(x, y, -1.0)
 
         # polar ticks
@@ -1818,8 +1816,8 @@ class PolarAxis2D(BaseAxis):
         minTickDist *= pix2c
         tickValues = ticksPerDim[0]  # can be None
 
-        tmp = GetPolarTicks(center_c, radiusMax_c, self._angularRange, \
-                            self._angularRefPos, self._sense, \
+        tmp = GetPolarTicks(center_c, radiusMax_c, self._angularRange,
+                            self._angularRefPos, self._sense,
                             minTickDist, tickValues)
         ticks, ticksPos, ticksText = tmp
         textRadius = (2.2 * txtSize) + radiusMax_c
@@ -1841,8 +1839,7 @@ class PolarAxis2D(BaseAxis):
 
             # Text is in word coordinates so need to create them based on ticks
             theta = self._angularRefPos + (self._sense * tick * np.pi / 180.0)
-            p2 = Point((textRadius * np.cos(theta))[0], \
-                       (textRadius * np.sin(theta))[0], 0)
+            p2 = Point((textRadius * np.cos(theta))[0], (textRadius * np.sin(theta))[0], 0)
             # Put a textlabel at tick
             textDict = self._textDicts[0]
             if tick in textDict and textDict[tick] in self._children:
@@ -1881,7 +1878,7 @@ class PolarAxis2D(BaseAxis):
         xc = radiusMax_c * np.cos(theta)
         yc = radiusMax_c * np.sin(theta)
 
-        for x, y in  np.column_stack((xc, yc)):
+        for x, y in np.column_stack((xc, yc)):
             ppc.append(0.0, 0.0, 0.0)
             ppc.append(x, y, 0.0)
 
@@ -1893,13 +1890,12 @@ class PolarAxis2D(BaseAxis):
         tickValues = ticksPerDim[1]  # can be None
 
         ticks, ticksPos, ticksText, quadIndex = [], [], [], []
-        for index, theta in  enumerate(self._angularRefPos + \
-            self._sense * np.array([0, np.pi / 2, np.pi, np.pi * 3 / 2])):
+        for index, theta in enumerate(self._angularRefPos +
+                    self._sense * np.array([0, np.pi / 2, np.pi, np.pi * 3 / 2])):
             xc = radiusMax_c * np.cos(theta)
             yc = radiusMax_c * np.sin(theta)
             p2 = Point(xc, yc, 0)
-            tmp = GetTicks(center_c, p2, Range(0, radiusMax_c), \
-                           minTickDist, tickValues)
+            tmp = GetTicks(center_c, p2, Range(0, radiusMax_c), minTickDist, tickValues)
             if index == 0:
                 ticks = ticks + tmp[0]
                 ticksPos = ticksPos + tmp[1]
@@ -1921,8 +1917,7 @@ class PolarAxis2D(BaseAxis):
             p1 = pos
             if (p1.norm() != 0):
                 tv = (4 * pix2c[0]) * p1 / p1.norm()
-                tvTxt = ((4 * pix2c[0]) + \
-                         txtSize[0].view(float)) * p1 / p1.norm()
+                tvTxt = ((4 * pix2c[0]) + txtSize[0].view(float)) * p1 / p1.norm()
             else:
                 tv = Point(0, 0, 0)
                 tvTxt = Point(-txtSize[0], 0, 0)
@@ -1970,7 +1965,7 @@ class PolarAxis2D(BaseAxis):
                 yc = tick * np.sin(theta)
                 xlast = xc[:-1][0]
                 ylast = yc[:-1][0]
-                for x, y in  np.column_stack((xc, yc)):
+                for x, y in np.column_stack((xc, yc)):
                     ppg.append(Point(xlast, ylast, 0.0))
                     ppg.append(Point(x, y, 0.0))
                     xlast = x
@@ -2086,11 +2081,9 @@ class PolarAxis2D(BaseAxis):
 
             if self.shiftIsDown:
                 minRadius = self.ref_lowerRadius - dy
-                self.SetLimits(rangeR=Range(minRadius, \
-                               minRadius + Rrange))
+                self.SetLimits(rangeR=Range(minRadius, minRadius + Rrange))
             else:
-                self.angularRefPos = self.ref_angularRefPos - \
-                                 (50 * dx / Rrange)
+                self.angularRefPos = self.ref_angularRefPos - (50 * dx / Rrange)
         
         elif self.ref_but == 2:
             # zoom
@@ -2107,8 +2100,7 @@ class PolarAxis2D(BaseAxis):
             
             # apply (use only y-factor ).
             Rrange = Rrange * math.exp(-factor_y)
-            self.SetLimits(rangeR=Range(self._radialRange.min, \
-                           self._radialRange.min + Rrange))
+            self.SetLimits(rangeR=Range(self._radialRange.min, self._radialRange.min + Rrange))
             self.ref_mloc = mloc
         self.Draw()
         return True
@@ -2148,7 +2140,7 @@ class PolarAxis2D(BaseAxis):
             raise ValueError("radial limits should be Range \
                                or two-element iterables.")
         
-        if rangeTheta != None:
+        if rangeTheta is not None:
             self._angularRange = rangeTheta
             
         
