@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-""" 
+"""
 This example illustrates the use of the Aarray class.
 Particularly how the class is aware of slicing and adapts
 the origin and sampling accordingly. Visvis uses the sampling
@@ -12,7 +12,7 @@ from visvis import Aarray
 app = vv.use()
 
 # Load image and make Aarray
-im = vv.imread('lena.png')
+im = vv.imread('astronaut.png')
 im = Aarray(im)
 
 # Cut in four pieces, but also change resolution using different step sizes
